==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/view_user.php <==
<?php
class ViewUser extends Ulyxex {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->pos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->numPages = 0;
	}
	public function user_data($userId) {
		$query = "SELECT ".
					"USERNAME,DESCRIPTION,MAIL".
				" FROM ".
					USERS.
				" WHERE ID=".$userId;
		$query = $this->q($query);
		$result = "";
		$line = @mysql_fetch_assoc($query);
		if ($line == 0){
			return $this->h->h3($this->tr->w("no user !"));
		}else{
			$result .= $this->h->h1($line['USERNAME'],"class='username'");
			$result .= $this->h->p($line['DESCRIPTION'],"class='userdescription'");
			$result .= $this->h->p($line['MAIL'],"class='usermail'");
			return $result;
		}
	}
	public function user_links($userId) {
		$result = "";
		$this->queryCommonOrderSort = " ORDER BY ID DATE LIMIT 0,".ADMINITEMSBYPAGE;
		$query = "SELECT ".
					"ID,CONTENT".
				" FROM ".
					ARTICLES.
				" WHERE ".
					"HIDE = 0 AND USERID=".$userId.
				" ORDER BY ".
					"DATE DESC LIMIT 0,".ADMINITEMSBYPAGE;
		$query = $this->q($query);
		$items = "";
		if ($query) {
			while ( $line = mysql_fetch_assoc($query) ) {
				$items.= $this->h->li($this->h->ahref("index.php?art=".$line['ID'],$this->h->shortLeft($line['CONTENT'],40)));
				$this->numPages = $this->numPages + 1;
			}
		}
		$result .= $this->h->h3($this->tr->w("last articles"),"class='articleslisttitle'").$this->h->ol($items,"class='articleslist'");
		
		$query = "SELECT ".
					"ID,DESCRIPTION".
				" FROM ".
					LINKS.
				" WHERE ".
					"HIDE = 0 AND USERID=".$userId.
				" ORDER BY ".
					"ID DESC LIMIT 0,".ADMINITEMSBYPAGE;					
		$query = $this->q($query);
		$items = "";
		if ($query) {
			while ( $line = mysql_fetch_assoc($query) ) {
				$items.= $this->h->li($this->h->ahref("index.php?page=link".$line['ID'],$this->h->shortLeft($line['DESCRIPTION'],40)));
				$this->numPages = $this->numPages + 1;
			}
		}
		$result .= $this->h->h3($this->tr->w("last links"),"class='linkslisttitle'").$this->h->ol($items,"class='linkslist'");
		return $result;
	}
}
?>

==> ulyxex.0.1.2.with-tinyMce.zip: pages/code/view_user.php <==
<?php
class ViewUser extends Ulyxex {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->pos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->numPages = 0;
	}
	public function user_data($userId) {
		$query = "SELECT ".
					"USERNAME,DESCRIPTION,MAIL".
				" FROM ".
					USERS.
				" WHERE ID=".$userId;
		$query = $this->q($query);
		$result = "";
		$line = @mysql_fetch_assoc($query);
		if ($line == 0){
			return $this->h->h3($this->tr->w("no user !"));
		}else{
			$result .= $this->h->h1($line['USERNAME'],"class='username'");
			$result .= $this->h->p($line['DESCRIPTION'],"class='userdescription'");
			$result .= $this->h->p($line['MAIL'],"class='usermail'");
			return $result;
		}
	}
	public function user_links($userId) {
		$result = "";
		$this->qOrderSort = " ORDER BY ID DATE LIMIT 0,".ADMINITEMSBYPAGE;
		$query = "SELECT ".
					"ID,CONTENT".
				" FROM ".
					ARTICLES.
				" WHERE ".
					"HIDE = 0 AND USERID=".$userId.
				" ORDER BY ".
					"DATE DESC LIMIT 0,".ADMINITEMSBYPAGE;
		$query = $this->q($query);
		$items = "";
		if ($line = mysql_fetch_assoc($query)) {
			$items.= $this->h->li($this->h->ahref("index.php?art=".$line['ID'],$this->h->shortLeft($line['CONTENT'],40)));
			$this->numPages = $this->numPages + 1;
			while ( $line = mysql_fetch_assoc($query) ) {
				$items.= $this->h->li($this->h->ahref("index.php?art=".$line['ID'],$this->h->shortLeft($line['CONTENT'],40)));
				$this->numPages = $this->numPages + 1;
			}
		}
		$result .= $this->h->h3($this->tr->w("last articles"),"class='articleslisttitle'").$this->h->ol($items,"class='articleslist'");
		
		$query = "SELECT ".
					"ID,DESCRIPTION".
				" FROM ".
					LINKS.
				" WHERE ".
					"HIDE = 0 AND USERID=".$userId.
				" ORDER BY ".
					"ID DESC LIMIT 0,".ADMINITEMSBYPAGE;					
		$query = $this->q($query);
		$items = "";
		if ($line = mysql_fetch_assoc($query)) {
			$items.= $this->h->li($this->h->ahref("index.php?navpage=link".$line['ID'],$this->h->shortLeft($line['DESCRIPTION'],40)));
			$this->numPages = $this->numPages + 1;
			while ( $line = mysql_fetch_assoc($query) ) {
				$items.= $this->h->li($this->h->ahref("index.php?navpage=link".$line['ID'],$this->h->shortLeft($line['DESCRIPTION'],40)));
				$this->numPages = $this->numPages + 1;
			}
		}
		$result .= $this->h->h3($this->tr->w("last links"),"class='linkslisttitle'").$this->h->ol($items,"class='linkslist'");
		return $result;
	}
}
?>
